// SettingsDialogGeneral.cpp : fichier d'implmentation
//

#include "resource.h"
#include "stdafx.h"
#include "AutDlg.h"
#include "SysTrayPlay.h"
#include "SettingsDialog.h"
#include "SettingsDialogGeneral.h"
#include "MainHelper.h"
#include "MainWnd.h"
#include "SeekDialog.h"
#include "EqualizerDlg.h"
#include "PlaylistDlg.h"
#include "In/MultiDllInput.h"
#include "Tools/cgfiltyp.h"
#include "Tools/Console.h"
#include "Tools/Draw.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

// Bote de dialogue CSettingGeneral

IMPLEMENT_MENUXP(CSettingsDialogGeneral, CPropertyPage);

IMPLEMENT_DYNAMIC(CSettingsDialogGeneral, CPropertyPage)

BOOL DeleteKeyAndSubKeys(HKEY    hkIn, LPCTSTR   pszSubKey)
{
	HKEY hk;
	TCHAR szTmp[MAX_PATH];
	long l;
	BOOL f;

	l = RegOpenKeyEx(hkIn, pszSubKey, 0, KEY_ALL_ACCESS, &hk);
	if (l != ERROR_SUCCESS)
		return FALSE;

	f = TRUE;
	while (f)
	{
		l = RegEnumKey(hk, 0, szTmp, MAX_PATH);
		if (l != ERROR_SUCCESS)
			break;
		f = DeleteKeyAndSubKeys(hk, szTmp);
	}

	RegCloseKey(hk);
	l = RegDeleteKey(hkIn, pszSubKey);

	return (l == ERROR_SUCCESS) ? TRUE : FALSE;
}

void CSettingsDialogGeneral::CreateContMenus()
{
	DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, _T("Directory\\Shell\\playstp"));
	DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, _T("Directory\\Shell\\addstp"));
	DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, _T("Drive\\Shell\\playstp"));
	DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, _T("Drive\\Shell\\addstp"));

	CString buf;

	TCHAR fname[MAX_PATH + 1];
	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH);

	CGCFileTypeAccess fileTypeAccess;

	if (((CButton *)GetDlgItem(IDC_CM_PLAY))->GetCheck() == 1)
	{
		// just pass file path in quotes on command line
		buf = fname;
		buf = "\"" + buf + "\"";
		buf += " \"%1\"";
		fileTypeAccess.SetShellOpenCommand(buf);
		fileTypeAccess.SetShellOpenDescription(LPCTSTR(m_Helper.MyLoadString(IDS_PLAYWITHSTP)));
	}

	if (((CButton *)GetDlgItem(IDC_CM_ADD))->GetCheck() == 1)
	{
		buf = fname;
		buf = "\"" + buf + "\"";
		buf += " -a";
		buf += " \"%1\"";
		fileTypeAccess.SetShellAddCommand(buf);
		fileTypeAccess.SetShellAddDescription(LPCTSTR(m_Helper.MyLoadString(IDS_ADDTOPLAYLIST)));
	}

	fileTypeAccess.SetExtension(_T("Directory"));
	fileTypeAccess.RegSetDirectory();

	fileTypeAccess.SetExtension(_T("Drive"));
	fileTypeAccess.RegSetDirectory();
}

CSettingsDialogGeneral::CSettingsDialogGeneral() : CPropertyPage(CSettingsDialogGeneral::IDD)
{
	m_tpc = pMainFrame->TPC;
	display = FALSE;
}

CSettingsDialogGeneral::~CSettingsDialogGeneral()
{
}


void CSettingsDialogGeneral::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	CMenuXP::SetXPLookNFeel(this, pMainFrame->XPLookNFeel);
	DDX_Text(pDX, IDC_TPC, m_tpc);
	DDX_Control(pDX, IDC_L_OPTIONS, m_l_options);
	DDX_Control(pDX, IDC_L_OPTIONS2, m_l_options2);
	DDX_Control(pDX, IDC_CHANGELANGUAGE, m_cbxLanguage);
	DDX_Control(pDX, IDC_SKIN, m_btnSkin);
}

int CSettingsDialogGeneral::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	m_Helper.translateWindowText(this, IDD_SETTINGS_GENERAL);
	return CPropertyPage::OnCreate(lpCreateStruct);
}

BOOL CSettingsDialogGeneral::OnInitDialog()
{
	CPropertyPage::OnInitDialog();

	m_Helper.translateWindowText(this, IDD_SETTINGS_GENERAL);
	m_Helper.translateDlgItemText(this, IDC_LTRACKPERCOLUMN);
	m_Helper.translateDlgItemText(this, IDC_LPRESSHOLD);
	m_Helper.translateDlgItemText(this, IDC_LUSECLICKS);
	m_Helper.translateDlgItemText(this, IDC_LSETUP);
	m_Helper.translateDlgItemText(this, IDC_LPLAYWITH);
	m_Helper.translateDlgItemText(this, IDC_LFOLDERMENU);
	m_Helper.translateDlgItemText(this, IDC_CM_PLAY);
	m_Helper.translateDlgItemText(this, IDC_CM_ADD);
	m_Helper.translateDlgItemText(this, IDC_ADDBYDEF);
	m_Helper.translateDlgItemText(this, IDC_SKIN);
	m_Helper.translateDlgItemText(this, IDC_W2F);
	m_Helper.translateDlgItemText(this, IDC_LADDITIONAL);
	m_Helper.translateDlgItemText(this, IDC_LLANGUAGE);

	m_tpc = pMainFrame->TPC;
	((CSpinButtonCtrl *)GetDlgItem(IDC_SPIN2))->SetRange(0, 100);

	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION0));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION1));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION7));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION2));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION3));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION4));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION8));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION6));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION9));
	m_l_options.AddString(m_Helper.MyLoadString(IDS_OPTION10));

	m_l_options.SetCheck(0, pMainFrame->ShowGradientBar ? 1 : 0);
	m_l_options.SetCheck(1, pMainFrame->GraphicalButtons ? 1 : 0);
	m_l_options.SetCheck(2, pMainFrame->XPLookNFeel);
	m_l_options.SetCheck(3, pMainFrame->SMTracks ? 1 : 0);
	m_l_options.SetCheck(4, pMainFrame->SMAlbum ? 1 : 0);
	m_l_options.SetCheck(5, pMainFrame->AutoPlay);
	m_l_options.SetCheck(6, pMainFrame->SMPrevNext ? 1 : 0);
	m_l_options.SetCheck(7, pMainFrame->WAEmu ? 1 : 0);
	m_l_options.SetCheck(8, pMainFrame->autoUpdate ? 1 : 0);
	m_l_options.SetCheck(9, (pMainFrame->displayConsole&&pConsole->IsVisible()) ? 1 : 0);
	display = m_l_options.GetCheck(9);

	CString extList = stdIn->GetFileExtensions();
	CString ext;
	int pos = 0,i = 0;
	defaultAdd = false;

	ext = extList.Tokenize(_T(";"), pos);
	while (ext != "")
	{
		if (extList.Find(ext, pos) != -1)
		{
			ext = extList.Tokenize(_T(";"), pos);
			continue;
		}
		m_l_options2.AddString(ext);

		if (ReadFileTypes(ext))
			m_l_options2.SetCheck(i, 1);
		else
			m_l_options2.SetCheck(i, 0);
		ext = extList.Tokenize(_T(";"), pos);
		i++;
	}
	if (defaultAdd)
		((CButton *)GetDlgItem(IDC_ADDBYDEF))->SetCheck(1);

	CFileFind finder;
	TCHAR buffer[MAX_PATH + 1];
	CString directory = "";
	CString name = "";
	CString language = "";

	GetModuleFileName(theApp.m_hInstance, buffer, MAX_PATH);
	directory.Format(_T("%s"), buffer);
	directory = directory.Left(directory.ReverseFind('\\') + 1);
	name.Format(_T("%s"), buffer);
	name = name.Right(name.GetLength() - name.ReverseFind('\\') - 1);
	name = name.Left(name.ReverseFind('.'));

	m_cbxLanguage.AddString(_T("en"));
	BOOL bWorking = finder.FindFile(directory + name + _T("_*.ini"));
	while (bWorking)
	{
		bWorking = finder.FindNextFile();
		language = finder.GetFilePath();
		language = language.Right(language.GetLength() - language.ReverseFind('_') - 1);
		language = language.Left(language.ReverseFind('.'));
		if (m_cbxLanguage.FindStringExact(0, language) == CB_ERR)
		{
			m_cbxLanguage.AddString(language);
		}
	}
	m_cbxLanguage.SetCurSel(0);
	CString tmp;

	for (int i = 0; i < m_cbxLanguage.GetCount(); i++)
	{
		m_cbxLanguage.GetLBText(i, tmp);
		if (pMainFrame->Language == tmp)
		{
			m_cbxLanguage.SetCurSel(i);
			break;
		}
	}
	ReadContMenus();

	return TRUE;  // return TRUE unless you set the focus to a control
	// EXCEPTION: OCX Property Pages should return FALSE
}

void CSettingsDialogGeneral::OnOK()
{
	UpdateData(TRUE);
	pMainFrame->TPC = m_tpc;

	pMainFrame->ShowGradientBar = m_l_options.GetCheck(0) == 1;
	pMainFrame->GraphicalButtons = m_l_options.GetCheck(1) == 1;
	if (pMainFrame->GraphicalButtons)
	{
		//Nettoyage manuel des textes pour viter la sur impression
		CMenuXP::ms_sCaptions.SetAt(ID_POPUPMENU_PLAY, (CString)_T(""));
		CMenuXP::ms_sCaptions.SetAt(ID_POPUPMENU_PAUSE, (CString)_T(""));
		CMenuXP::ms_sCaptions.SetAt(ID_POPUPMENU_STOP, (CString)_T(""));
		CMenuXP::ms_sCaptions.SetAt(ID_POPUPMENU_PREVIOUS, (CString)_T(""));
		CMenuXP::ms_sCaptions.SetAt(ID_POPUPMENU_NEXT, (CString)_T(""));
	}
	//if (pMainFrame->XPLookNFeel != (m_l_options.GetCheck(2) == 1))
	//	pMainFrame->needToRestart = true;
	pMainFrame->XPLookNFeel = m_l_options.GetCheck(2);
	CMenuXP::SetXPLookNFeel(pMainFrame, pMainFrame->XPLookNFeel);
	pMainFrame->SMTracks = m_l_options.GetCheck(3) == 1;
	pMainFrame->SMAlbum = m_l_options.GetCheck(4) == 1;
	pMainFrame->AutoPlay = m_l_options.GetCheck(5);
	pMainFrame->SMPrevNext = m_l_options.GetCheck(6) == 1;
#ifndef _UNICODE
	if (pMainFrame->WAEmu != (m_l_options.GetCheck(7) == 1))
		pMainFrame->needToRestart = true;
#else
	if (m_l_options.GetCheck(7) == 1)
		AfxMessageBox(m_Helper.MyLoadString(IDS_OPTION6) + _T("\n") + m_Helper.MyLoadString(IDS_UNICODEERROR), MB_OK | MB_ICONERROR);
#endif
	pMainFrame->WAEmu = m_l_options.GetCheck(7) == 1;
	pMainFrame->autoUpdate = m_l_options.GetCheck(8) == 1;
	pMainFrame->displayConsole = m_l_options.GetCheck(9) == 1;
	theApp.WriteProfileInt(_T("Preferences"), _T("displayConsole"), pMainFrame->displayConsole ? 1 : 0);
	CString tmp;

	m_cbxLanguage.GetLBText(m_cbxLanguage.GetCurSel(), tmp);
	if (tmp.Find(_T("en")) != -1)
	{
		theApp.WriteProfileString(_T("Preferences"), _T("Language"), _T(""));
		pMainFrame->Language = "";
	}
	else
	{
		theApp.WriteProfileString(_T("Preferences"), _T("Language"), tmp);
		pMainFrame->Language = tmp;
	}

	RegFileTypes();
	CreateContMenus();

	if (pMainFrame->displayConsole)
		pConsole->Popup();

	CPropertyPage::OnOK();
}

void CSettingsDialogGeneral::OnPopupLoad()
{
	// open a skin file
	CFileDialog dialog(TRUE, _T("skn"), _T(""), OFN_FILEMUSTEXIST | OFN_HIDEREADONLY, m_Helper.MyLoadString(IDS_OPENSKIN));
	TCHAR buf[MAX_PATH + 1];
	GetModuleFileName(theApp.m_hInstance, buf, MAX_PATH);
	for (int i = _tcslen(buf) - 1; i > 0; i--)
	{
		if (buf[i] == '\\')
		{
			buf[i + 1] = '\0';break;
		}
	}
	dialog.m_ofn.lpstrInitialDir = buf;
	int ret;
	ret = dialog.DoModal();
	if (ret == IDOK)
	{
		
		CString tmp = dialog.GetPathName();
		if(SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.FindString(0, tmp)==-1)
		{
			SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.AddString(tmp);
		}
		SettingsDialog->CurrentSkinSel = SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.FindString(0, tmp);
		SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.SetCurSel(SettingsDialog->CurrentSkinSel);
		pMainFrame->LoadSkin(tmp, &SettingsDialog->loadSkin);
		pMainFrame->UseSkin(&SettingsDialog->loadSkin);
		CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
		SettingsDialog->DisplaySkin(pWnd);
	}
}

void CSettingsDialogGeneral::OnPopupUseDefault()
{
	CString tmp = m_Helper.MyLoadString(IDS_DEFAULTSKIN);
	if(SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.FindString(0, tmp)==-1)
	{
		SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.AddString(tmp);
	}
	SettingsDialog->CurrentSkinSel = SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.FindString(0, tmp);
	SettingsDialog->m_SettingsDialogApparenceSkins.m_ListSkin.SetCurSel(SettingsDialog->CurrentSkinSel);
	pMainFrame->LoadSkin(tmp, &SettingsDialog->loadSkin);
	pMainFrame->UseSkin(&SettingsDialog->loadSkin);
	CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
	SettingsDialog->DisplaySkin(pWnd);
}

void CSettingsDialogGeneral::OnSkin()
{
	CMenu menu;
	CMenu* pPopup;
	menu.LoadMenu(IDR_SKINPOPUP);
	pPopup = menu.GetSubMenu(0);
	m_Helper.translateMenu(pPopup, IDR_SKINPOPUP);
	CMenuXP::UpdateMenuBar(this);

	CRect rect;
	GetDlgItem(IDC_SKIN)->GetWindowRect(&rect);
	POINT point;
	point.x = (rect.left + rect.right) / 2;
	point.y = (rect.top + rect.bottom) / 2;
	pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_RIGHTBUTTON, point.x, point.y, this);
	CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
	SettingsDialog->DisplaySkin(pWnd);
}

void CSettingsDialogGeneral::OnPaint()
{
	CPropertyPage::OnPaint();
	CPaintDC dc(this);
	CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
	SettingsDialog->DisplaySkin(pWnd);
}

void CSettingsDialogGeneral::RegFileTypes()
{
	TCHAR fname[MAX_PATH + 1];
	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH);
	bool enqdef = (((CButton*)GetDlgItem(IDC_ADDBYDEF))->GetCheck() == 1);

	HKEY q;
	unsigned long z, mp;

	CString buf;
	for (int i = 0; i < m_l_options2.GetCount(); i++)
	{
		CString extension = "";
		m_l_options2.GetText(i, extension);
		CString dotExtension = ".";
		dotExtension.Append(extension.MakeLower());

		CString key = _T("STP");
		key.Append(extension.MakeUpper());
		// Efface de STPExtension
		DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, key);

		CString defaultIcon = key;
		defaultIcon.Append(_T("\\DefaultIcon"));
		CString shell = key;
		shell.Append(_T("\\Shell"));
		CString shellOpen = shell;
		shellOpen.Append(_T("\\Open"));
		CString shellOpenCommand = shellOpen;
		shellOpenCommand.Append(_T("\\Command"));
		CString shellAdd = shell;
		shellAdd.Append(_T("\\Add"));
		CString shellAddCommand = shellAdd;
		shellAddCommand.Append(_T("\\Command"));

		CGCFileTypeAccess fileTypeAccess;

		fileTypeAccess.SetExtension(extension);
		fileTypeAccess.SetDocumentDescription(LPCTSTR(m_Helper.MyLoadString(IDS_MP3AUDIO)));
		// use first icon in program
		buf = fname;
		buf += ",0";
		fileTypeAccess.SetDocumentDefaultIcon(buf);
		if (enqdef)
			fileTypeAccess.SetDocumentDefault(_T("addstp"));
		else
			fileTypeAccess.SetDocumentDefault(_T("openstp"));
		// just pass file path in quotes on command line
		buf = "\"";
		buf += fname;
		buf += "\"";
		buf += " \"%1\"";
		fileTypeAccess.SetShellOpenCommand(buf);
		fileTypeAccess.SetShellOpenDescription(LPCTSTR(m_Helper.MyLoadString(IDS_MENUOPEN)));
		fileTypeAccess.SetDocumentShellOpenCommand(buf);
		fileTypeAccess.SetDocumentShellOpenDescription(LPCTSTR(m_Helper.MyLoadString(IDS_MENUOPEN)));

		buf = "\"";
		buf += fname;
		buf += "\"";
		buf += " -a \"%1\"";
		fileTypeAccess.SetShellAddCommand(buf);
		fileTypeAccess.SetShellAddDescription(LPCTSTR(m_Helper.MyLoadString(IDS_ADDTOPLAYLIST)));
		fileTypeAccess.SetDocumentShellAddCommand(buf);
		fileTypeAccess.SetDocumentShellAddDescription(LPCTSTR(m_Helper.MyLoadString(IDS_ADDTOPLAYLIST)));
		fileTypeAccess.SetDocumentClassName(key);

		if (m_l_options2.GetCheck(i) == 1)
		{
			fileTypeAccess.RegSetAllExtensionInfo();
		}
		else
		{
			//Effacement paramtre par dfaut
			if (RegOpenKeyEx(HKEY_CLASSES_ROOT, dotExtension, 0, KEY_READ, &q) == ERROR_SUCCESS)
			{
				TCHAR fname[MAX_PATH + 1];
				z = REG_SZ;mp = MAX_PATH;
				if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
				{
					if (key.CompareNoCase(fname) == 0)
					{
						fileTypeAccess.SetRegistryValue(HKEY_CLASSES_ROOT, dotExtension, _T(""), _T(""));
					}
				}
				RegCloseKey(q);
			}

			//Effacement de addstp si = stp
			CString dotExtensionAdd = dotExtension + "\\shell\\addstp\\command";
			if (RegOpenKeyEx(HKEY_CLASSES_ROOT, dotExtensionAdd, 0, KEY_READ, &q) == ERROR_SUCCESS)
			{
				TCHAR fname[MAX_PATH + 1];
				z = REG_SZ;mp = MAX_PATH;
				if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
				{
					CString addCommand;
					fileTypeAccess.GetShellAddCommand(addCommand);
					if (addCommand.CompareNoCase(fname) == 0)
					{
						dotExtensionAdd = dotExtension + "\\shell\\addstp";
						DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, dotExtensionAdd);
					}
				}
				RegCloseKey(q);
			}
			//Effacement de openstp si = stp
			CString dotExtensionOpen = dotExtension + "\\shell\\openstp\\command";
			if (RegOpenKeyEx(HKEY_CLASSES_ROOT, dotExtensionOpen, 0, KEY_READ, &q) == ERROR_SUCCESS)
			{
				TCHAR fname[MAX_PATH + 1];
				z = REG_SZ;mp = MAX_PATH;
				if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
				{
					CString openCommand;
					fileTypeAccess.GetShellOpenCommand(openCommand);
					if (openCommand.CompareNoCase(fname) == 0)
					{
						dotExtensionOpen = dotExtension + "\\shell\\openstp";
						DeleteKeyAndSubKeys(HKEY_CLASSES_ROOT, dotExtensionOpen);
					}
				}
				RegCloseKey(q);
			}
		}
	}
}


void CSettingsDialogGeneral::ReadContMenus()
{
	HKEY q;    
	unsigned long z, mp;

	bool PrevPlay = true, PrevAdd = true;

	TCHAR fname[MAX_PATH + 1];
	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH); 
	CString mFile = _T("\"");
	mFile += fname;
	mFile += _T("\" \"%1\"");

	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, _T("Directory\\Shell\\playstp\\Command"), 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) != 0)
				PrevPlay = false;
		}
		else
			PrevPlay = false;
		RegCloseKey(q);
	}
	else
		PrevPlay = false;

	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH); 
	mFile = "\"";
	mFile += fname;
	mFile += "\" \"%1\"";
	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, _T("Drive\\Shell\\playstp\\Command"), 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) != 0)
				PrevPlay = false;
		}
		else
			PrevPlay = false;
		RegCloseKey(q);
	}
	else
		PrevPlay = false;

	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH); 
	mFile = "\"";
	mFile += fname;
	mFile += "\" -a \"%1\"";

	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, _T("Directory\\Shell\\addstp\\Command"), 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) != 0)
				PrevAdd = false;
		}
		else
			PrevAdd = false;
		RegCloseKey(q);
	}
	else
		PrevAdd = false;

	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH); 
	mFile = "\"";
	mFile += fname;
	mFile += "\" -a \"%1\"";

	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, _T("Drive\\Shell\\addstp\\Command"), 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) != 0)
				PrevAdd = false;
		}
		else
			PrevAdd = false;
		RegCloseKey(q);
	}
	else
		PrevAdd = false;

	if (PrevPlay)
		((CButton *)GetDlgItem(IDC_CM_PLAY))->SetCheck(1);
	if (PrevAdd)
		((CButton *)GetDlgItem(IDC_CM_ADD))->SetCheck(1);
}

bool CSettingsDialogGeneral::ReadFileTypes(CString ext)
{
	CString dotExtension = ".";
	dotExtension.Append(ext.MakeLower());

	CString key = _T("STP");
	key.Append(ext.MakeUpper());

	CString shell = key;
	shell.Append(_T("\\Shell"));
	CString shellOpen = shell;
	shellOpen.Append(_T("\\Open"));
	CString shellOpenCommand = shellOpen;
	shellOpenCommand.Append(_T("\\Command"));
	CString shellAdd = shell;
	shellAdd.Append(_T("\\Add"));
	CString shellAddCommand = shellAdd;
	shellAddCommand.Append(_T("\\Command"));

	TCHAR fname[MAX_PATH + 1];
	GetModuleFileName(theApp.m_hInstance, fname, MAX_PATH); 
	CString mFile;
	mFile = "\"";
	mFile += fname;
	mFile += "\"";
	mFile += " -a \"%1\"";

	HKEY q;
	unsigned long z;
	unsigned long mp; 

	int qq = 0;

	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, key, 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		qq++;
	}

	CString dotExtensionAdd = dotExtension + "\\shell\\addstp\\command";
	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, dotExtensionAdd, 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		TCHAR fname[MAX_PATH + 1];
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) == 0)
			{
				qq++;
			}
		}
		RegCloseKey(q);
	}

	mFile = "\"";
	mFile += fname;
	mFile += "\"";
	mFile += " -a \"%1\"";

	CString dotExtensionOpen = dotExtension + "\\shell\\openstp\\command";
	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, dotExtensionAdd, 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		TCHAR fname[MAX_PATH + 1];
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) == 0)
			{
				qq++;
			}
		}
		RegCloseKey(q);
	}

	mFile = "addstp";
	CString shellExt = key + "\\shell";
	if (RegOpenKeyEx(HKEY_CLASSES_ROOT, shellExt, 0, KEY_READ, &q) == ERROR_SUCCESS)
	{
		TCHAR fname[MAX_PATH + 1];
		z = REG_SZ;mp = MAX_PATH;
		if (RegQueryValueEx(q, _T(""), NULL, &z, (LPBYTE)fname, &mp) == ERROR_SUCCESS)
		{
			if (mFile.CompareNoCase(fname) == 0)
			{
				defaultAdd = true;
			}
		}
		RegCloseKey(q);
	}

	return qq != 0;
}

BEGIN_MESSAGE_MAP(CSettingsDialogGeneral, CPropertyPage)
	ON_BN_CLICKED(IDC_SKIN, OnSkin)
	ON_COMMAND(ID_POPUP_LOAD, OnPopupLoad)
	ON_COMMAND(ID_POPUP_USEDEFAULT, OnPopupUseDefault)
	ON_WM_CREATE()
	ON_WM_PAINT()
	ON_WM_MOUSEMOVE()
	ON_LBN_SELCHANGE(IDC_L_OPTIONS, OnLbnSelchangeLOptions)
END_MESSAGE_MAP()

void CSettingsDialogGeneral::OnMouseMove(UINT nFlags, CPoint point)
{
	CRect rect;
	GetDlgItem(IDC_SKINSAMPLE)->GetWindowRect(&rect);
	ScreenToClient(rect);
	CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
	if (rect.PtInRect(point))
	{
		int frg = -1;
		frg = 5 * (point.y - rect.top) / rect.Height();
		SettingsDialog->DisplaySkin(pWnd, frg);
	}
	else
	{
		SettingsDialog->DisplaySkin(pWnd);
	}
}
void CSettingsDialogGeneral::OnLbnSelchangeLOptions()
{
	CWnd* pWnd = GetDlgItem(IDC_SKINSAMPLE);
	SettingsDialog->DisplaySkin(pWnd);
	UpdateData(TRUE);
	if(display != m_l_options.GetCheck(9))
	{
		display = m_l_options.GetCheck(9);
		if (m_l_options.GetCheck(9) == 1)
		{
			pConsole->Popup();
		} 
		else
		{
			pConsole->Close();
		}
		theApp.WriteProfileInt(_T("Preferences"), _T("displayConsole"), pMainFrame->displayConsole ? 1 : 0);
	}
}
